@@ -11,23 +11,7 @@
 # Copyright (c) 2017, Even Rouault <even dot rouault at spatialys dot com>
 # Copyright (c) 2021, Idan Miara <idan@miara.com>
 #
-# Permission is hereby granted, free of charge, to any person obtaining a
-# copy of this software and associated documentation files (the "Software"),
-# to deal in the Software without restriction, including without limitation
-# the rights to use, copy, modify, merge, publish, distribute, sublicense,
-# and/or sell copies of the Software, and to permit persons to whom the
-# Software is furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included
-# in all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
-# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
-# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
-# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
-# DEALINGS IN THE SOFTWARE.
+# SPDX-License-Identifier: MIT
 ###############################################################################
 
 import glob
@@ -43,7 +27,7 @@ from osgeo_utils.auxiliary.util import GetOutputDriverFor, enable_gdal_exception
 
 def Usage(isError):
     f = sys.stderr if isError else sys.stdout
-    print("Usage: ogrmerge.py [--help] [--help-general]", file=f)
+    print("Usage: ogrmerge [--help] [--help-general]", file=f)
     print("            -o <out_dsname> <src_dsname> [<src_dsname>]...", file=f)
     print("            [-f <format>] [-single] [-nln <layer_name_template>]", file=f)
     print("            [-update | -overwrite_ds] [-append | -overwrite_layer]", file=f)
